@@ -93,6 +93,27 @@ class SH_FLAGS(object):
     SHF_MASKPROC=0xf0000000
 
 
+class RH_FLAGS(object):
+    """ Flag values for the DT_MIPS_FLAGS dynamic table entries
+    """
+    RHF_NONE=0x00000000
+    RHF_QUICKSTART=0x00000001
+    RHF_NOTPOT=0x00000002
+    RHF_NO_LIBRARY_REPLACEMENT=0x00000004
+    RHF_NO_MOVE=0x00000008
+    RHF_SGI_ONLY=0x00000010
+    RHF_GUARANTEE_INIT=0x00000020
+    RHF_DELTA_C_PLUS_PLUS=0x00000040
+    RHF_GUARANTEE_START_INIT=0x00000080
+    RHF_PIXIE=0x00000100
+    RHF_DEFAULT_DELAY_LOAD=0x00000200
+    RHF_REQUICKSTART=0x00000400
+    RHF_REQUICKSTARTED=0x00000800
+    RHF_CORD=0x00001000
+    RHF_NO_UNRES_UNDEF=0x00002000
+    RHF_RLD_ORDER_SAFE=0x00004000
+
+
 class P_FLAGS(object):
     """ Flag values for the p_flags field of program headers
     """
@@ -123,4 +144,4 @@ class SUNW_SYMINFO_FLAGS(object):
 class VER_FLAGS(object):
     VER_FLG_BASE=0x1
     VER_FLG_WEAK=0x2
-    VER_FLG_INFO=0x4 
+    VER_FLG_INFO=0x4
