@@ -361,7 +361,8 @@ ENUM_SH_TYPE_MIPS = merge_dicts(
             SHT_MIPS_WHIRL=0x70000026,
             SHT_MIPS_EH_REGION=0x70000027,
             SHT_MIPS_XLATE_OLD=0x70000028,
-            SHT_MIPS_PDR_EXCEPTION=0x70000029))
+            SHT_MIPS_PDR_EXCEPTION=0x70000029,
+            SHT_MIPS_ABIFLAGS=0x7000002a))
 
 ENUM_ELFCOMPRESS_TYPE = dict(
     ELFCOMPRESS_ZLIB=1,
@@ -396,6 +397,7 @@ ENUM_P_TYPE_BASE = dict(
     PT_GNU_EH_FRAME=0x6474e550,
     PT_GNU_STACK=0x6474e551,
     PT_GNU_RELRO=0x6474e552,
+    PT_GNU_PROPERTY=0x6474e553,
     _default_=Pass,
 )
 
@@ -783,6 +785,7 @@ ENUM_RELOC_TYPE_x64 = dict(
     R_X86_64_TLSDESC_CALL=35,
     R_X86_64_TLSDESC=36,
     R_X86_64_IRELATIVE=37,
+    R_X86_64_REX_GOTPCRELX=42,
     R_X86_64_GNU_VTINHERIT=250,
     R_X86_64_GNU_VTENTRY=251,
     _default_=Pass,
